==> clo-tetris-game-0.0.2.tar.gz: clo-tetris-game-0.0.2/tetris_game/constantes.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
dir_path = os.path.dirname(os.path.realpath(__file__))

MAIN_SONG = os.path.join(dir_path, 'assets/mainSong.wav')

BRICK_IMG = os.path.join(dir_path,"assets/brique.png")

WALL_SONG = os.path.join(dir_path,'assets/wall.wav')

LINE_SONG = os.path.join(dir_path,'assets/line.wav')

LOOSE_SONG = os.path.join(dir_path,'assets/loose.wav')

LEVEL_UP_SONG = os.path.join(dir_path,'assets/levelup.wav')

SCORE_FILE = os.path.join(dir_path,"score.csv")

LEVELS = {1 : 360,
          2 : 320,
          3 : 290,
          4 : 250,
          5 : 220,
          6 : 180,
          7 : 150,
          8 : 110,
          9 : 70,
          10: 50,
          11: 40,
          12: 40,
          13: 40,
          14: 30,
          15: 30,
          16: 30,
          17: 20,
          18: 20,
          19: 20,
          20: 10}

SHAPES={}

COLORS = ["red", "green", "blue", "cyan", "yellow", "magenta"]

SHAPES['O']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['I']=[
[
    [0, 0, 0, 0],
    [1, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0]
],

[
    [0, 0, 0, 0],
    [1, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0]
]]

SHAPES['S']=[
[
    [0, 0, 0, 0],
    [0, 0, 1, 1],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 0, 1, 1],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 1],
    [0, 0, 0, 0]
]]

SHAPES['Z']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 1],
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 1],
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['L']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 1],
    [0, 1, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 1],
    [0, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 1, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['J']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 1],
    [0, 0, 0, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 1, 0, 0],
    [0, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['T']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
]]

==> clo-tetris-game-0.0.6.tar.gz: clo-tetris-game-0.0.6/tetris_game/constantes.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
DIR_PATH = os.path.dirname(os.path.realpath(__file__))

MAIN_SONG = os.path.join(DIR_PATH, 'assets/mainSong.wav')

BRICK_IMG = os.path.join(DIR_PATH,"assets/brique.png")

WALL_SONG = os.path.join(DIR_PATH,'assets/wall.wav')

LINE_SONG = os.path.join(DIR_PATH,'assets/line.wav')

LOOSE_SONG = os.path.join(DIR_PATH,'assets/loose.wav')

LEVEL_UP_SONG = os.path.join(DIR_PATH,'assets/levelup.wav')

SCORE_FILE = os.path.join(DIR_PATH,"score.csv")

ICON_FILE = os.path.join(DIR_PATH,"assets/tetris.ico")

LEVELS = {1 : 360,
          2 : 320,
          3 : 290,
          4 : 250,
          5 : 220,
          6 : 200,
          7 : 190,
          8 : 190,
          9 : 190,
          10: 170,
          11: 170,
          12: 170,
          13: 160,
          14: 160,
          15: 160,
          16: 150,
          17: 150,
          18: 150,
          19: 100,
          20: 100}

SHAPES={}

COLORS = ["red", "green", "blue", "cyan", "yellow", "magenta"]

SHAPES['O']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['I']=[
[
    [0, 0, 0, 0],
    [1, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0]
],

[
    [0, 0, 0, 0],
    [1, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0]
]]

SHAPES['S']=[
[
    [0, 0, 0, 0],
    [0, 0, 1, 1],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 0, 1, 1],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 1],
    [0, 0, 0, 0]
]]

SHAPES['Z']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 1],
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 0],
    [0, 1, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 1],
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['L']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 1],
    [0, 1, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 0, 1],
    [0, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 1, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['J']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 1],
    [0, 0, 0, 1],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 1, 0, 0],
    [0, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 0, 0]
]]

SHAPES['T']=[
[
    [0, 0, 0, 0],
    [0, 1, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 0, 1, 1],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 1, 1, 1],
    [0, 0, 0, 0],
    [0, 0, 0, 0]
],

[
    [0, 0, 1, 0],
    [0, 1, 1, 0],
    [0, 0, 1, 0],
    [0, 0, 0, 0]
]]
